/*
** Copyright 2011-2013 Merethis
**
** This file is part of Centreon Clib.
**
** Centreon Clib is free software: you can redistribute it
** and/or modify it under the terms of the GNU Affero General Public
** License as published by the Free Software Foundation, either version
** 3 of the License, or (at your option) any later version.
**
** Centreon Clib is distributed in the hope that it will be
** useful, but WITHOUT ANY WARRANTY; without even the implied warranty
** of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
** Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public
** License along with Centreon Clib. If not, see
** <http://www.gnu.org/licenses/>.
*/

#include <cstdlib>
#include "com/centreon/clib.hh"
#include "com/centreon/logging/engine.hh"
#include "com/centreon/process_manager.hh"

using namespace com::centreon;

// Class instance.
static clib* _instance = NULL;

/**************************************
*                                     *
*           Public Methods            *
*                                     *
**************************************/

/**
 *  Load the clib singleton.
 *
 *  @param[in] flags Specify which elements should be loaded.
 */
void clib::load(unsigned int flags) {
  delete _instance;
  _instance = NULL;
  _instance = new clib(flags);
  return;
}

/**
 *  Unload the clib singleton.
 */
void clib::unload() {
  delete _instance;
  _instance = NULL;
  return;
}

/**************************************
*                                     *
*           Private Methods           *
*                                     *
**************************************/

/**
 *  Constructor.
 *
 *  @param[in] flags Specify which elements to load.
 */
clib::clib(unsigned int flags) {
  if (flags & with_logging_engine)
    logging::engine::load();
  if (flags & with_process_manager)
    process_manager::load();
}

/**
 *  Destructor.
 */
clib::~clib() throw () {
  process_manager::unload();
  logging::engine::unload();
}
